Developer Guide
===============

So you want to help develop Glue? Great, let's get started! :)

First, be sure to join the `glueviz-dev
<https://groups.google.com/forum/#!forum/glue-viz-dev>`_ mailing list for any
questions or discussions related to development, and let us know if any of the
documentation below is unclear. You are also very welcome to introduce yourself on the list and let us know that you are interested in contributing!

If you are going to be developing Glue, we recommend that you familiarize yourself with the rest of the documentation, and in particular the :ref:`glue architecture <architecture>` documentation, which describes in detail how some of the Glue internals work (although there are still a number of areas on which you can work without understanding all the internals in detail).

If you want to contribute, but don't yet have a specific idea of where to make contributions, you can check out our :ref:`guide to picking issues <issue_guide>`!

The following pages provide logistical information about the layout of the code, coding and testing guidelines, and some more advanced topics:

.. toctree::
   :maxdepth: 1

   issues.rst
   organization.rst
   roadmap.rst
   qt_development.rst
   coding_guidelines.rst
   testing.rst
   app_building.rst
